
ANTsR_Name ANTsPy_Name Description 
abpN4 |  | 
affineInitializer |  |   a multi-start optimizer for affine registration
mean |  |,antsImage-method   arith.antsImage
antsImageClone |  |  
antsMotionCalculation |  |   Correct 4D time-series data for motion.
antsRegistration |  |    
antsImagePhysicalSpaceConsistency |  |   Check for physical space consistency
antsImageRead |  |   
antsrimpute |  | 
antsImageHeaderInfo |  | Read file info from image header
antsMotionCorr |  |  Motion Correction
antsImageGetSet |  | antsImageGetSet
antsImageMutualInformation |  |  mutual information between two images
antsImageWrite |  |  
antsSetPixels |  |   Set a pixel value at an index
aslDenoiseR |  | 
aslPerfusion |  |    
antsTransformIndexToPhysicalPoint |  |   Get Spatial Point from Index
as.antsImage  |  |
antsTransformPhysicalPointToIndex |  |   Get Index from Spatial Point
antsSpatialICAfMRI |  |  
aslOutlierRejection |  | Pair-wise subtraction based outlier rejection.
atropos |  | FMM Segmentation
as.antsMatrix |  |   as.antsMatrix
combineNuisancePredictors |  |   Combine and reduce dimensionality of nuisance predictors.
clusterTimeSeries |  |   Split time series image into k distinct images
bigLMStats |  |  
bayesianlm |  |  Simple bayesian regression function.
computeDVARS |  |    computeDVARS
compcor |  | 
basicInPaint |  |    Inpaints missing imaging data from boundary data
bayesianCBF |  | Uses probabilistic segmentation to constrain pcasl-based cbf computation.
blockStimulus |  |   
bold_correlation_matrix |  | bold_correlation_matrix
crossvalidatedR2 |  |    Cross-Validated R^2 value
createJacobianDeterminantImage |  |  createJacobianDeterminantImage
DesikanKillianyTourville |  |    DesikanKillianyTourville
eigSeg |  |  
cropImage |  |   crop a sub-image via a mask
cropIndices |  | crop a sub-image by image indices
convolveImage |  |   convolve one image with another
corw |  |    
cvEigenanatomy |  |  
decropImage |  | decrop a sub-image back into the full image
getMask |  | 
getfMRInuisanceVariables |  |    
getNeighborhoodInMask |  |   Get neighborhoods for voxels within mask
getPixels |  |   Get Pixels
icawhiten |  |   
image2ClusterImages |  | 
imageFileNames2ImageList |  |    
imageListToMatrix |  |   
iMath |  |   iMath
iMathOps |  |    iMathOps
maskImage |  |   
matrix2timeseries |  |   Simple matrix2timeseries function.
getAverageOfTimeSeries |  |  
getCentroids |  |    
hemodynamicRF |  |   Linear Model for FMRI Data
iBind |  |   iBind
initializeEigenanatomy |  |  
interleaveMatrixWithItself |  |  
labelStats |  |  labelStats
lappend |  | 
makeGraph |  |   
makeImage |  |   
partialVolumeCorrection |  | 
projectImageAlongAxis |  |   
perfusionregression |  | 
quantifyCBF |  | 
sparseDecom |  | 
sparseDecom2 |  |    
usePkg |  |  Use any package. If package is not installed, this will install from CRAN.
vwnrfs |  |  voxelwise neighborhood random forest segmentation and prediction
antsApplyTransforms |  | 
n4BiasFieldCorrection |  |   Bias Field Correction
reorientImage |  |   reorient image by its principal axis
renderSurfaceFunction |  |   
rfSegmentationPredict |  |   
subjectDataToGroupDataFrame |  | 
timeseries2matrix |  |   
rsfDenoise |  |  
taskFMRI |  |    
timeseriesN3 |  |    Run N3 on slices of timeseries.
filterfMRIforNetworkAnalysis |  |    
getNeighborhoodAtVoxel |  |  Get a hypercube neighborhood at a voxel
imagesToMatrix |  |  
getMultivariateTemplateCoordinates |  |  
lowrankRowMatrix |  |    Produces a low rank version of the input matrix
imageMath |  |   R access to the ANTs program ImageMath
labelGeometryMeasures |  |   labelGeometryMeasures
labelImageCentroids |  | labelImageCentroids
frequencyFilterfMRI |  | 
antsBOLDNetworkAnalysis |  | a basic framework for network analysis that produces graph metrics
antsCopyImageInfo |  |   Copy header info
getANTsRData |  |    getANTsRData
plotBasicNetwork |  |    
getASLNoisePredictors |  |   Get nuisance predictors from ASL images
is.antsImage   |  |  is.antsImage
joinEigenanatomy |  |    
invariantImageSimilarity |  |    similarity metrics between two images as a function of geometry
jointIntensityFusion |  |    joint intensity fusion
aal |  | aal
plot.antsImage |  | Plotting an image slice or multi-slice with optional color overlay.
abpBrainExtraction |  |  
getTemplateCoordinates |  |  
extractSlice |  |    extract a slice from an image
%>%  |  |  Pipe an object forward
exemplarInpainting |  |  Uses example images to inpaint or approximate an existing image.
quantifySNPs |  |    Simple quantifySNPs function.
rapidlyInspectImageData |  | Simple rapidlyInspectImageData function.
whiten |  |  
temporalwhiten |  |  
thresholdImage |  |  Threshold Image
jointIntensityFusion3D |  |  jointIntensityFusion3D
antsAverageImages |  |   Computes average of image list
kellyKapowski |  |   Compute cortical thickness using the DiReCT algorithm.
mrvnrfs  |  | multi-res voxelwise neighborhood random forest segmentation learning
mrvnrfs.predict  |  |  multi-res voxelwise neighborhood random forest segmentation
n3BiasFieldCorrection |  |   Bias Field Correction
plotPrettyGraph |  | 
preprocessfMRI |  |  Preprocess BOLD fMRI image data.
reflectImage |  |    reflectImage
sparseDecom2boot |  |    
sparseDecomboot |  | 
regressionNetworkViz |  |    
timeserieswindow2matrix |  | 
tracts |  |  tracts
save.ANTsR  |  | save.ANTsR
segmentShapeFromImage |  |   convolution-based shape identification
kmeansSegmentation |  |  k means image segmentation.
labelClusters |  |   
matrixToImages |  |  
networkEiganat |  |  
mni2tal |  | 
pairwiseImageDistanceMatrix |  | 
regressProjections |  |  
renderImageLabels |  |   
sliceTimingCorrection |  |   slice timing correction for fMRI.
sparseRegression |  |    
smoothImage |  | Smooth image
spatialbayesianlm |  |   spatially constrained bayesian regression function.
make3ViewPNG |  |    
resampleImage |  |   resampleImage
rfSegmentation |  |  
splitData |  |   
subgradientL1Regression |  | 
antsPreprocessfMRI |  |  
as.matrix   |  | 
as.numeric   |  |
perfusion-predictors   |  |  
getROIValues |  |    
phantom_population_study |  |    
fastwhiten |  |  
Motion-Correction  |  |   
sccan |  |   
as.antsImage  |  |    
as.array   |  |
MeasureMinMaxMean |  |   
plotANTsImage |  |   
renderNetwork |  |   
visualizeBlob |  |   
inspectImageData3D |  |  
antsImage-class  |  | 
CBF |  | 
simple_roi_analysis |  | 
simple_voxel_based_analysis |  | 
KellyKapowski |  |   
Atropos |  | 
Extract |  | 
SmoothImage |  | 
N3BiasFieldCorrection |  |   
ImageMath |  |   
Comparison |  |  
ThresholdImage |  |  
antsMatrix-class   |  |  An S4 class to hold an antsMatrix imported from ITK types
antsRegion-class   |  |  An S4 class to hold a region of an antsImage
%>%  |  | Pipe an object forward
